<?php

namespace Drupal\views_permissions_strict\Plugin\views\access;

use Drupal\Core\Session\AccountInterface;
use Drupal\Core\StringTranslation\TranslatableMarkup;
use Drupal\user\Entity\Role;
use Drupal\user\Plugin\views\access\Permission;
use Drupal\views\Attribute\ViewsAccess;

/**
 * Access plugin that provides strict access control at all.
 *
 * @ingroup views_access_plugins
 */
#[ViewsAccess(
  id: 'views_permissions_strict_access',
  title: new TranslatableMarkup('Permission strict roles'),
  help: new TranslatableMarkup('Access will be granted to users with all roles in the permission.'),
)]
class ViewsCustomPermissionsAccess extends Permission {

  /**
   * {@inheritdoc}
   */
  public function access(AccountInterface $account) {
    if (in_array('administrator', $account->getRoles(), TRUE)) {
      return TRUE;
    }
    $permissionRole = $this->getRolesWithPermission($this->options['perm']);
    $permissionRole = array_diff($permissionRole, ['administrator']);
    $userRole = $account->getRoles();
    $userRole = array_diff($userRole, ['authenticated']);
    return empty(array_diff($permissionRole, $userRole));
  }

  /**
   * Helper function to get roles with the specified permission.
   *
   * @param string $permission_name
   *   The permission name to check.
   *
   * @return array
   *   An array of role IDs that have the specified permission.
   */
  private function getRolesWithPermission($permission_name) {
    $roles_with_permission = [];
    $roles = Role::loadMultiple();

    foreach ($roles as $role_id => $role) {
      if ($role->hasPermission($permission_name)) {
        $roles_with_permission[] = $role_id;
      }
    }

    return $roles_with_permission;
  }

}
