<?php

namespace Drupal\views_permissions_strict\Plugin\views\area;

use Drupal\Component\Utility\Html;
use Drupal\Core\Form\FormStateInterface;
use Drupal\views\Attribute\ViewsArea;
use Drupal\views\Plugin\views\area\Text;

/**
 * Views area text handler.
 *
 * @ingroup views_area_handlers
 */
#[ViewsArea("twig_custom")]
class TwigCustom extends Text {

  /**
   * {@inheritdoc}
   */
  public function buildOptionsForm(&$form, FormStateInterface $form_state) {
    parent::buildOptionsForm($form, $form_state);
    $form['content']['#editor'] = TRUE;
    $form['content']['#format'] = 'full_html';
    $form['content']['#allowed_formats'] = ['full_html'];
    $form['content']['#description'] = [
      '#theme' => 'item_list',
      '#items' => [
        '{{args}} -- arguments of views',
        '{{start}} -- the initial record number in the set',
        '{{end}} -- the last record number in the set',
        '{{total}} -- the total records in the set',
        '{{label}} -- the human-readable name of the view',
        '{{per_page}} -- the number of items per page',
        '{{current_page}} -- the current page number',
        '{{current_record_count}} -- the current page record count',
        '{{page_count}} -- the total page count',
      ],
    ];
  }

  /**
   * {@inheritdoc}
   */
  public function render($empty = FALSE) {
    if (!$empty || !empty($this->options['empty'])) {
      $current_page = (int) $this->view->getCurrentPage() + 1;
      $per_page = (int) $this->view->getItemsPerPage();
      $end = $total = $this->view->total_rows ?? count($this->view->result);
      $label = Html::escape($this->view->storage->label());
      $start = $start_offset = $total ? 1 : 0;
      $page_count = $per_page === 0 ? 1 : (int) ceil($total / $per_page);
      if ($per_page !== 0) {
        $total_count = $current_page * $per_page;
        if ($total_count > $total) {
          $total_count = $total;
        }
        $start = ($current_page - 1) * $per_page + $start_offset;
        $end = $total_count;
      }
      $current_record_count = ($end - $start) + $start_offset;
      $template = $this->options['tokenize'] ? $this->tokenizeValue($this->options['content']['value']) : $this->options['content']['value'];
      return [
        '#type' => 'inline_template',
        '#template' => $template,
        '#context' => [
          'args' => $this->view->args,
          'current_page' => $current_page,
          'per_page' => $per_page,
          'total' => $total,
          'label' => $label,
          'current_record_count' => $current_record_count,
          'page_count' => $page_count,
        ],
      ];
    }
    return [];
  }

}
