<?php

namespace Drupal\views_permissions_strict\Plugin\views\field;

use Drupal\Core\Form\FormStateInterface;
use Drupal\views\Attribute\ViewsField;
use Drupal\views\Plugin\views\field\Custom;
use Drupal\views\Render\ViewsRenderPipelineMarkup;
use Drupal\views\ResultRow;

/**
 * Provides a field handler that renders a log event with replaced variables.
 *
 * @ingroup views_field_handlers
 */
#[ViewsField("twig_custom")]
class TwigCustom extends Custom {

  /**
   * {@inheritdoc}
   */
  public function buildOptionsForm(&$form, FormStateInterface $form_state) {
    parent::buildOptionsForm($form, $form_state);

    // Remove the description.
    unset($form['alter']['text']['#description']);
  }

  /**
   * {@inheritdoc}
   */
  public function render(ResultRow $values) {
    // Return the text, so the code never thinks the value is empty.
    return ViewsRenderPipelineMarkup::create($this->options['alter']['text']);
  }

  /**
   * {@inheritdoc}
   */
  protected function allowAdvancedRender() {
    $backtrace = debug_backtrace(DEBUG_BACKTRACE_IGNORE_ARGS, 2);
    $callerMethod = $backtrace[1]['function'];
    if ($callerMethod == 'buildOptionsForm') {
      return TRUE;
    }
    return FALSE;
  }

}
